<?php

namespace AcyCheckerCmsServices;


class Router
{
    public static function addScript($raw, $script, $type = 'text/javascript', $defer = false, $async = false, $needTagScript = false, $deps = ['jquery'])
    {
        static $scriptNumber = 0;
        $scriptNumber++;
        if ($raw) {
            if (!empty($deps['script_name'])) {
                wp_add_inline_script($deps['script_name'], $script);
            } else {
                echo '<script type="'.$type.'">'.$script.'</script>';
            }
        } elseif ($defer || $async || $needTagScript) {
            echo '<script type="'.$type.'" src="'.$script.'"'.($async ? ' async' : '').($defer ? ' defer' : '').'></script>';
        } else {
            wp_enqueue_script('script'.$scriptNumber, $script, $deps);
        }

        return 'script'.$scriptNumber;
    }

    public static function addStyle($raw, $style, $type = 'text/css', $media = null, $attribs = [])
    {
        if ($raw) {
            echo '<style type="'.$type.'"'.(empty($media) ? '' : ' media="'.$media.'"').'>'.$style.'</style>';
        } else {
            echo '<link rel="stylesheet" href="'.$style.'" type="'.$type.'"'.(empty($media) ? '' : ' media="'.$media.'"').'>';
        }
    }

    public static function redirect($url, $msg = '', $msgType = 'message', $safe = false)
    {
        if (Security::isAdmin() && substr($url, 0, 4) != 'http' && substr($url, 0, 4) != 'www.') {
            $url = Url::addPageParam($url);
        }
        @ob_get_clean();
        if (empty($url)) $url = Url::rootURI();
        if (headers_sent()) {
            Router::addScript(true, 'window.location.href = "'.addslashes($url).'";');
        } else {
            if ($safe) {
                wp_safe_redirect($url);
            } else {
                wp_redirect($url);
            }
        }
        exit;
    }
}
