<?php


namespace AcyChecker\Controllers;


use AcyChecker\Classes\TestClass;
use AcyChecker\Libraries\AcycController;
use AcyChecker\Services\DebugService;
use AcyChecker\Services\PaginationService;
use AcyCheckerCmsServices\Language;
use AcyCheckerCmsServices\Security;
use AcyCheckerCmsServices\Url;

class TestsController extends AcycController
{
    const PAGINATION_NAME = 'test_pagination';

    private $paginationName;
    private $testClass;

    public function __construct()
    {
        parent::__construct();

        $this->name = 'Tests';
        $this->defaultTask = 'listing';

        $this->testClass = new TestClass();
    }

    public function listing()
    {
        $this->layout = 'listing';

        $data = [
            'per_page' => 20,
            'search' => $this->getVarFiltersListing('string', 'search', ''),
            'page' => $this->getVarFiltersListing('int', self::PAGINATION_NAME, 1),
            'current_status' => $this->getVarFiltersListing('string', 'status', ''),
        ];

        $this->prepareTestsElements($data);
        $this->preparePagination($data);
        $this->prepareTexts($data);
        $this->prepareStatus($data);

        $this->breadcrumb[__('Tests', 'acychecker')] = Url::completeLink('tests');

        $this->display($data);
    }

    private function prepareTestsElements(&$data)
    {
        $data['offset'] = ($data['page'] - 1) * $data['per_page'];
        $data = array_merge($data, $this->testClass->getMatchingElements($data));
    }

    private function preparePagination(&$data)
    {
        $data['pagination'] = new PaginationService($data['page'], $data['total'], $data['per_page'], self::PAGINATION_NAME);
    }

    private function prepareTexts(&$data)
    {
        $data['final_status_texts'] = [
            'not_existing' => __('Not existing', 'acychecker'),
            'risky' => __('Risky', 'acychecker'),
            'possible' => __('Possible', 'acychecker'),
            'valid' => __('Valid', 'acychecker'),
        ];
    }

    private function prepareStatus(&$data)
    {
        $data['status'] = [
            'all' => [
                'text' => __('All', 'acychecker'),
                'number' => $this->testClass->getStatusNumber('all', $data),
                'value' => 'all',
            ],
            'tested' => [
                'text' => __('Tested', 'acychecker'),
                'number' => $this->testClass->getStatusNumber('tested', $data),
                'value' => 'tested',
            ],
            'progress' => [
                'text' => __('In progress', 'acychecker'),
                'number' => $this->testClass->getStatusNumber('progress', $data),
                'value' => 'progress',
            ],
        ];
    }
}
