<?php

namespace AcyChecker\Services;

use AcyChecker\Libraries\AcycObject;
use AcyCheckerCmsServices\Extension;
use AcyCheckerCmsServices\Language;

class ConfigurationService extends AcycObject
{
    public static function prepareTableSelect(&$data)
    {
        $data['tables_select'] = [
            [
                'value' => 'cms',
                'text' => sprintf(__('%s users', 'acychecker'), ACYC_CMS_TITLE),
            ],
        ];

        $acymExtension = 'joomla' == ACYC_CMS ? ACYC_ACYMAILING_COMPONENT : ACYC_ACYMAILING_COMPONENT.'/index.php';
        if (Extension::isExtensionActive($acymExtension)) {
            $data['tables_select'][] = [
                'value' => 'acymailing',
                'text' => sprintf(__('%s users', 'acychecker'), 'AcyMailing'),
            ];
        }
    }

    public static function prepareConditionSelect(&$data)
    {
        $data['condition_select'] = [
            [
                'value' => 'disposable',
                'text' => __('Is a disposable email address', 'acychecker'),
                'description' => __('This test check if the email address of the user is a temporary one or not, for example email addresses created on yopmail', 'acychecker'),
            ],
            [
                'value' => 'accept_all',
                'text' => __('Is an accept all email address', 'acychecker'),
                'description' => __('Accept all means that no matters which email address you have on this domain it will be redirected on a default inbox of the SMTP server', 'acychecker'),
            ],
            [
                'value' => 'free_domain',
                'text' => __('Is registered through a free domain', 'acychecker'),
                'description' => __('This means that the user is using a free mail provider like Gmail, Yahoo or outlook', 'acychecker'),
            ],
            [
                'value' => 'role_based',
                'text' => __('Is a role based email address', 'acychecker'),
                'description' => __('This means that email address is assigned to a team and not a person for example sales@acyba.com', 'acychecker'),
            ],
            [
                'value' => 'domain_not_exists',
                'text' => __('Is registered through a non-existent domain', 'acychecker'),
                'description' => __('This means that the domain does not exist', 'acychecker'),
            ],
            [
                'value' => 'invalid_smtp',
                'text' => __('Does not exist on the SMTP server of the domain', 'acychecker'),
                'description' => __('This means that we ask to the SMTP server of the subscriber if the email address exist', 'acychecker'),
            ],
        ];
    }
}
