<?php


namespace AcyChecker\Services;


use AcyCheckerCmsServices\Language;
use AcyCheckerCmsServices\Security;

class FormService
{


    /**
     * @param array  $data     Can be in format $data[value] = text or $data[1] = object
     * @param string $name
     * @param array  $selected
     * @param array  $attribs  All attributes to add to the select in this format $data["class"] = "my_class"
     * @param string $optValue Value name identifier to access by $value = object->$optValue
     * @param string $optText  Text name identifier to access by $text = object->$optText
     * @param bool   $translate
     *
     * @return string
     */
    public static function selectMultiple($data, $name, $selected = [], $attribs = [], $optValue = 'value', $optText = 'text', $translate = false)
    {
        if (substr($name, -2) !== '[]') {
            $name .= '[]';
        }

        $attribs['multiple'] = 'multiple';

        $dropdown = '<select name="'.Security::escape($name).'"';
        foreach ($attribs as $attribKey => $attribValue) {
            $dropdown .= ' '.$attribKey.'="'.addslashes($attribValue).'"';
        }
        $dropdown .= '>';

        foreach ($data as $oneDataKey => $oneDataValue) {
            $disabled = '';

            if (is_object($oneDataValue)) {
                $value = $oneDataValue->$optValue;
                $text = $oneDataValue->$optText;

                if (!empty($oneDataValue->disable)) {
                    $disabled = ' disabled="disabled"';
                }
            } else {
                $value = $oneDataKey;
                $text = $oneDataValue;
            }

            if ($translate) {
                $text = Language::translation($text);
            }

            if (strtolower($value) == '<optgroup>') {
                $dropdown .= '<optgroup label="'.Security::escape($text).'">';
            } elseif (strtolower($value) == '</optgroup>') {
                $dropdown .= '</optgroup>';
            } else {
                $text = Security::escape($text);
                $dropdown .= '<option value="'.Security::escape($value).'"'.(in_array($value, $selected) ? ' selected="selected"' : '').$disabled.'>'.$text.'</option>';
            }
        }

        $dropdown .= '</select>';

        return $dropdown;
    }
}
